#!/bin/bash
# maintainer        : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package			: planner
# homepage			: http://live.gnome.org/Planner
# source location	: http://ftp.gnome.org/pub/GNOME/sources/planner/0.14/planner-0.14.4.tar.gz
# dependency        : 

softname='planner'
softversion='0.14.4'
packageversion='64.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://ftp.gnome.org/pub/GNOME/sources/planner/0.14/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
planner: planner - project management
planner:
planner: A bounty is being offered for an implementation of resource 
planner: allocation/leveling.
planner: 
planner:
planner:
planner:
planner:
planner:
planner:
EOF



# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# configure package and install it to the target directory
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--disable-schemas-install \
	--with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
	--build=$arch-slackware-linux || exit

make 
make install DESTDIR=$dest

# gconf stuff
 export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
     # Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
 fi 

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Project Management
Name[am]=የዕቅድ ጉባኤ
Name[ar]=إدارة المشروع
Name[be]=Кіраваньне праектам
Name[bg]=Управление на проекти
Name[ca]=Gestió de projectes
Name[cs]=Správa projektů
Name[da]=Værktøj til projektstyring
Name[de]=Planner Projektverwaltung
Name[dz]=ལས་འགུལ་འཛིན་སྐྱོང་།
Name[el]=Διαχείριση έργων
Name[en_CA]=Project Management
Name[en_GB]=Project Management
Name[es]=Gestión de proyectos
Name[et]=Projektihaldus
Name[eu]=Proiektu-kudeaketa
Name[fa]=مدیریت پروژه
Name[fi]=Projektinhallinta
Name[fr]=Gestionnaire de projets
Name[gl]=Xestión de proxectos
Name[hi]=प्रोजेक्ट प्रबंधन
Name[hr]=Upravljanje projektima
Name[hu]=Projektmenedzsment
Name[is]=Verkstjórnun
Name[it]=Gestione progetti
Name[ja]=Planner プロジェクト管理
Name[ko]=프로젝트 관리
Name[lt]=Projektų valdymas
Name[lv]=Projekta pārvaldība
Name[ml]=പദ്ധതിനിര്‍വ്വഹണം
Name[ms]=Pengurusan Projek
Name[nb]=Prosjektstyring
Name[ne]=परियोजना व्यवस्थापन
Name[nl]=Project Management
Name[oc]=Gestion de projècte
Name[pl]=Zarządzanie projektami
Name[pt]=Gestão de Projectos
Name[pt_BR]=Gerência de Projetos
Name[ru]=Управление проектами
Name[sk]=Správca projektov
Name[sl]=Upravljanje projektov
Name[sr]=Управљање пројектима
Name[sr@Latn]=Upravljanje projektima
Name[sv]=Projekthantering
Name[ta]=திட்ட மேலாண்மை
Name[tr]=Proje Yönetimi
Name[uk]=Керування проектами
Name[vi]=Quản lý dự án
Name[zh_CN]=项目管理
Name[zh_HK]=專案管理
Name[zh_TW]=專案管理
Comment=Planner Project Management
Comment[ar]=إدارة مشاريع المُخَطِّط
Comment[bg]=Управление на проекти (Planner)
Comment[ca]=Gestor de projectes del Planner
Comment[cs]=Správa projektů Planner
Comment[da]=Planner-projektstyring
Comment[de]=Planner Projektverwaltung
Comment[dz]=རྩམ་མི་ལས་འགུལ་འཛིན་སྐྱོང་།
Comment[el]=Διαχείριση έργων Planner
Comment[en_CA]=Planner Project Management
Comment[en_GB]=Planner Project Management
Comment[es]=Gestor de proyectos Planner
Comment[et]=Plaanija projektihaldus
Comment[eu]=Planner proiektu-kudeaketa
Comment[fa]=مدیریت پروژه‌ی برنامه‌ریز
Comment[fi]=Planner-projektinhallinta
Comment[fr]=Gestionnaire de projets Planner
Comment[gl]=Xestor de proxectos Planner
Comment[hr]=Plannerovo upravljanje projektima
Comment[hu]=Planner projektmenedzsment
Comment[it]=Planner gestione progetto
Comment[ja]=プロジェクトを管理します
Comment[ko]=Planner 프로젝트 관리 프로그램
Comment[lt]=Planner projektų valdymas
Comment[lv]=Plānotaja projekta pārvaldība
Comment[nb]=Planner prosjektstyring
Comment[ne]=योजनाकर्ता परियोजना व्यवस्थापन
Comment[nl]=Planner Project Management
Comment[pt]=Gestão de Projectos Planner
Comment[pt_BR]=Gerenciador de Projetos Planner
Comment[ru]=Planner управление проектами
Comment[sk]=Správa projektov Planner
Comment[sl]=Planer: upravljanje projektov
Comment[sr]=Управљање пројектима Планером
Comment[sr@Latn]=Upravljanje projektima Planerom
Comment[sv]=Planner projekthantering
Comment[ta]=திட்டமமைப்பானின் திட்ட மேலாண்மை
Comment[tr]=Planner Proje Yönetimi
Comment[uk]=Керування проектами Planner
Comment[vi]=Quản lý dự án Planner
Comment[zh_CN]=Planner 项目管理
Comment[zh_HK]=Planner 專案管理
Comment[zh_TW]=Planner 專案管理
Exec=planner %F
Icon=gnome-planner
Terminal=false
Type=Application
Categories=Application;Office;ProjectManagement;
StartupNotify=true
MimeType=application/x-planner;
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=planner
X-GNOME-Bugzilla-Component=General
X-GNOME-Bugzilla-Version=0.14.3
EOF

cat << "EOF" > $dest/install/doinst.sh
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
     usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
     usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
EOF

# Fix icon
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/gnome-$softname.png  gnome-$softname.png 

# add 'default' files
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion
    cp $dest/usr/share/doc/planner/* $dest/usr/doc/$softname-$softversion/
	rm -rf $dest/usr/share/doc
	rm -rf $dest/usr/share/gtk-doc
	
# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "alsa-lib,atk,audiofile,avahi,cairo,dbus,dbus-glib,esound,expat,fontconfig,\
freetype,gcc,gcc-g++,gconf,glib2,gnome-keyring,gnome-vfs,gtk+2,libICE,libSM,libX11,\
libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,\
libXrandr,libXrender,libart_lgpl,libbonobo,libbonoboui,libgcrypt,libglade,libgnome,libgnomecanvas,\
libgnomeui,libgpg-error,libpng,libxcb,libxml2,libxslt,openssl,orbit2,pango,pixman,popt,util-linux-ng,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/planner/source/build-planner.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
